summaryrefslogtreecommitdiffstats
path: root/konq-plugins/validators/plugin_validators.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-18 17:00:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-18 17:00:31 +0000
commit395a904bff7b4d6ead445c342f7ac0c5fbf29121 (patch)
tree9829cadb79d2cc7c29a940627fadb28b11e54150 /konq-plugins/validators/plugin_validators.cpp
parent399f47c376fdf4d19192732a701ea9578d11619d (diff)
downloadtdeaddons-395a904bff7b4d6ead445c342f7ac0c5fbf29121.tar.gz
tdeaddons-395a904bff7b4d6ead445c342f7ac0c5fbf29121.zip
TQt4 port kdeaddons
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeaddons@1237404 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konq-plugins/validators/plugin_validators.cpp')
-rw-r--r--konq-plugins/validators/plugin_validators.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/konq-plugins/validators/plugin_validators.cpp b/konq-plugins/validators/plugin_validators.cpp
index f669308..3ee1f91 100644
--- a/konq-plugins/validators/plugin_validators.cpp
+++ b/konq-plugins/validators/plugin_validators.cpp
@@ -44,9 +44,9 @@ static const KAboutData aboutdata("validatorsplugin", I18N_NOOP("Validate Web Pa
K_EXPORT_COMPONENT_FACTORY( libvalidatorsplugin,
PluginValidatorsFactory( &aboutdata ) )
-PluginValidators::PluginValidators( TQObject* parent, const char* name,
+PluginValidators::PluginValidators( TQObject* tqparent, const char* name,
const TQStringList & )
- : Plugin( parent, name ), m_configDialog(0), m_part(0)
+ : Plugin( tqparent, name ), m_configDialog(0), m_part(0)
{
setInstance(PluginValidatorsFactory::instance());
@@ -71,14 +71,14 @@ PluginValidators::PluginValidators( TQObject* parent, const char* name,
m_menu->setEnabled( false );
- if ( parent && parent->inherits( "KHTMLPart" ))
+ if ( tqparent && tqparent->inherits( "KHTMLPart" ))
{
m_menu->insert( new KAction( i18n( "C&onfigure Validator..." ),
"configure", 0,
this, TQT_SLOT(slotConfigure()),
actionCollection(), "configure") );
- m_part = static_cast<KHTMLPart *>( parent );
+ m_part = static_cast<KHTMLPart *>( tqparent );
m_configDialog = new ValidatorsDialog( m_part->widget() );
setURLs();
@@ -90,7 +90,7 @@ PluginValidators::PluginValidators( TQObject* parent, const char* name,
PluginValidators::~PluginValidators()
{
delete m_configDialog;
// Dont' delete the action. KActionCollection as parent does the job already
// and not deleting it at this point also ensures that in case we are not unplugged
// from the GUI yet and the ~KXMLGUIClient destructor will do so it won't hit a
// dead pointer. The kxmlgui factory keeps references to the actions, but it does not
@@ -140,8 +140,8 @@ void PluginValidators::slotConfigure()
void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
{
- // The parent is assumed to be a KHTMLPart
- if ( !parent()->inherits("KHTMLPart") )
+ // The tqparent is assumed to be a KHTMLPart
+ if ( !tqparent()->inherits("KHTMLPart") )
{
TQString title = i18n( "Cannot Validate Source" );
TQString text = i18n( "You cannot validate anything except web pages with "
@@ -181,10 +181,10 @@ void PluginValidators::validateURL(const KURL &url, const KURL &uploadUrl)
{
KMessageBox::sorry(
m_part->widget(),
- i18n("<qt>The selected URL cannot be verified because it contains "
+ i18n("<qt>The selected URL cannot be verified because it tqcontains "
"a password. Sending this URL to <b>%1</b> would put the security "
"of <b>%2</b> at risk.</qt>")
- .arg(validatorUrl.host()).arg(partUrl.host()));
+ .tqarg(validatorUrl.host()).tqarg(partUrl.host()));
return;
}
// Set entered URL as a parameter
@@ -90,7 +90,7 @@ PluginValidators::PluginValidators( TQObject* parent, const char* name,
{
delete m_configDialog;
-// Dont' delete the action. KActionCollection as parent does the job already
+// Dont' delete the action. KActionCollection as tqparent does the job already
// and not deleting it at this point also ensures that in case we are not unplugged
// from the GUI yet and the ~KXMLGUIClient destructor will do so it won't hit a